from collections.abc import Mapping
from pathlib import Path
import pickle
from typing import Any, Optional

from ansys.fluent.core.launcher.launcher import FluentVersion
from ansys.fluent.core.services.datamodel_se import PyMenu, PyNamedObjectContainer
from ansys.fluent.core.services.datamodel_tui import TUIMenu
from ansys.fluent.core.session_pure_meshing import PureMeshing
from ansys.fluent.core.session_solver import Solver
from ansys.fluent.core.solver import flobject
from ansys.fluent.core.utils.fluent_version import get_version_for_filepath
from ansys.fluent.core.workflow import BaseTask, TaskContainer, WorkflowWrapper


def get_api_tree_filepath(version: str, pyfluent_path: str) -> Path:
    return (
        (
            (Path(pyfluent_path) / "ansys" / "fluent" / "core")
            if pyfluent_path
            else (Path(__file__) / ".." / "..")
        )
        / "data"
        / f"api_tree_{version}.pickle"
    ).resolve()


def _match(source: str, word: str, match_whole_word: bool, match_case: bool):
    if not match_case:
        source = source.lower()
        word = word.lower()
    if match_whole_word:
        return source == word
    else:
        return word in source


def _remove_suffix(input: str, suffix):
    if hasattr(input, "removesuffix"):
        return input.removesuffix(suffix)
    else:
        if suffix and input.endswith(suffix):
            return input[: -len(suffix)]
        return input


_meshing_rules = ["workflow", "meshing", "PartManagement", "PMFileManagement"]


def _get_version_path_prefix_from_obj(obj: Any):
    path = None
    version = None
    prefix = None
    if isinstance(obj, PureMeshing):
        path = ["<meshing_session>"]
        version = get_version_for_filepath(obj.get_fluent_version())
        prefix = "<search_root>"
    elif isinstance(obj, Solver):
        path = ["<solver_session>"]
        version = get_version_for_filepath(obj.get_fluent_version())
        prefix = "<search_root>"
    elif isinstance(obj, TUIMenu):
        module = obj.__class__.__module__
        path = [
            "<meshing_session>"
            if module.startswith("ansys.fluent.core.meshing")
            else "<solver_session>",
            "tui",
        ]
        path.extend(obj._path)
        version = module.rsplit("_", 1)[-1]
        prefix = "<search_root>"
    elif isinstance(obj, WorkflowWrapper):
        path = ["<meshing_session>", obj.rules]
        module = obj._workflow.__class__.__module__
        module = _remove_suffix(module, ".workflow")
        version = module.rsplit("_", 1)[-1]
        prefix = "<search_root>"
    elif isinstance(obj, BaseTask):
        path = ["<meshing_session>", obj.rules]
        path.extend([f"{k[0]}:<name>" if k[1] else k[0] for k in obj.path])
        module = obj._workflow.__class__.__module__
        module = _remove_suffix(module, ".workflow")
        version = module.rsplit("_", 1)[-1]
        prefix = "<search_root>"
    elif isinstance(obj, TaskContainer):
        path = ["<meshing_session>", obj.rules]
        path.extend([f"{k[0]}:<name>" if k[1] else k[0] for k in obj.path])
        path[-1] = f"{path[-1]}:<name>"
        module = obj._container._workflow.__class__.__module__
        module = _remove_suffix(module, ".workflow")
        version = module.rsplit("_", 1)[-1]
        prefix = '<search_root>["<name>"]'
    elif isinstance(obj, PyMenu):
        rules = obj.rules
        path = ["<meshing_session>" if rules in _meshing_rules else "<solver_session>"]
        path.append(rules)
        path.extend([f"{k[0]}:<name>" if k[1] else k[0] for k in obj.path])
        module = obj.__class__.__module__
        module = _remove_suffix(module, f".{rules}")
        version = module.rsplit("_", 1)[-1]
        prefix = "<search_root>"
    elif isinstance(obj, PyNamedObjectContainer):
        rules = obj.rules
        path = ["<meshing_session>" if rules in _meshing_rules else "<solver_session>"]
        path.append(rules)
        path.extend([f"{k[0]}:<name>" if k[1] else k[0] for k in obj.path])
        path[-1] = f"{path[-1]}:<name>"
        module = obj.__class__.__module__
        module = _remove_suffix(module, f".{rules}")
        version = module.rsplit("_", 1)[-1]
        prefix = '<search_root>["<name>"]'
    elif isinstance(obj, flobject.Group):
        module = obj.__class__.__module__
        version = module.split(".")[-2].rsplit("_", 1)[-1]
        prefix = "<search_root>"
        path = ["<solver_session>"]
        # Cannot deduce the whole path without api_tree
    elif isinstance(obj, flobject.NamedObject):
        module = obj.__class__.__module__
        version = module.split(".")[-2].rsplit("_", 1)[-1]
        prefix = '<search_root>["<name>"]'
        path = ["<solver_session>"]
        # Cannot deduce the whole path without api_tree
    return version, path, prefix


def search(
    word: str,
    match_whole_word: bool = False,
    match_case: bool = False,
    version: Optional[str] = None,
    search_root: Optional[Any] = None,
):
    """
    Search for a word through the Fluent's object hierarchy.

    Parameters
    ----------
    word : str
        The word to search for.
    match_whole_word : bool, optional
        Whether to match whole word, by default False
    match_case : bool, optional
        Whether to match case, by default False
    version : str, optional
        Fluent version to search in, by default None in which case
        it will search in the latest version for which codegen was run.
    search_root : Any, optional
        The root object within which the search will be performed,
        can be a session object or any API object within a session,
        by default None in which case it will search everything.

    Examples
    --------
    >>> import ansys.fluent.core as pyfluent
    >>> pyfluent.search("geometry")
    <meshing_session>.tui.file.import_.cad_geometry (Command)
    <meshing_session>.tui.display.update_scene.select_geometry (Command)
    <meshing_session>.meshing.ImportGeometry (Command)
    <meshing_session>.meshing.LoadCADGeometry (Command)
    <solver_session>.tui.solve.initialize.compute_defaults.geometry (Command)
    <solver_session>.tui.report.reference_values.compute.geometry (Command)
    <solver_session>.tui.define.geometry (Command)
    <solver_session>.tui.mesh.geometry (Object)
    <solver_session>.setup.boundary_conditions.geometry["<name>"] (Object)
    <solver_session>.setup.geometry (Object)
    <solver_session>.solution.report_definitions.surface["<name>"].geometry (Parameter)
    <solver_session>.solution.report_definitions.volume["<name>"].geometry (Parameter)
    <solver_session>.results.graphics.mesh["<name>"].geometry (Parameter)
    <solver_session>.results.graphics.contour["<name>"].geometry (Parameter)
    """
    if version:
        version = get_version_for_filepath(version)
    root_version, root_path, prefix = _get_version_path_prefix_from_obj(search_root)
    if search_root and not prefix:
        return
    if not version:
        version = root_version
    if not version:
        for fluent_version in FluentVersion:
            version = get_version_for_filepath(str(fluent_version))
            if get_api_tree_filepath(version, None).exists():
                break
    api_tree_file = get_api_tree_filepath(version, None)
    with open(api_tree_file, "rb") as f:
        api_tree = pickle.load(f)

    if isinstance(search_root, (flobject.Group, flobject.NamedObject)):
        path = root_path + [
            flobject.to_python_name(x) for x in search_root.path.split("/")
        ]
        root_path = []
        tree = api_tree
        while path:
            p = path.pop(0)
            if p in tree:
                tree = tree[p]
                root_path.append(p)
            elif f"{p}:<name>" in tree:
                tree = tree[f"{p}:<name>"]
                root_path.append(f"{p}:<name>")
                if path:
                    path.pop(0)
            else:
                return

    def inner(tree, path, root_path):
        if root_path:
            path = prefix
        while root_path:
            p = root_path.pop(0)
            if p in tree:
                tree = tree[p]
            else:
                return

        for k, v in tree.items():
            if k in ("<meshing_session>", "<solver_session>"):
                next_path = k
            else:
                if k.endswith(":<name>"):
                    k = _remove_suffix(k, ":<name>")
                    next_path = f'{path}.{k}["<name>"]'
                else:
                    next_path = f"{path}.{k}"
                if _match(k, word, match_whole_word, match_case):
                    type_ = "Object" if isinstance(v, Mapping) else v
                    print(f"{next_path} ({type_})")
            if isinstance(v, Mapping):
                inner(v, next_path, root_path)

    inner(api_tree, "", root_path)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .si_delete import si_delete as si_delete_cls
class delete(Command):
    """
    Delete a mesh interface.
    
    Parameters
    ----------
        si_delete : str
            'si_delete' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['si_delete']

    si_delete: si_delete_cls = si_delete_cls
    """
    si_delete argument of delete.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class adapt:
    fluent_name = ...
    child_names = ...
    refinement_criteria = ...
    coarsening_criteria = ...
    manual_refinement_criteria = ...
    manual_coarsening_criteria = ...
    set = ...
    profile = ...
    free_hierarchy = ...
    multi_layer_refinement = ...
    geometry = ...
    command_names = ...

    def adapt_mesh(self, ):
        """
        Adapt the mesh based on set refinement/coarsening criterion.
        """

    def display_adaption_cells(self, ):
        """
        Display cells marked for refinement/coarsening.
        """

    def list_adaption_cells(self, ):
        """
        List the number of cells marked for refinement/coarsening.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_1 import file_name as file_name_cls
class read_settings(Command):
    """
    Read and set boundary conditions from specified file.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
    
    """

    fluent_name = "read-settings"

    argument_names = \
        ['file_name']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of read_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class hide_environment_keep_effects(Boolean):
    """
    Hide 3D HDRI environment texture but keep its effect for rendering.
    """

    fluent_name = "hide-environment-keep-effects?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .sc_def_file_settings import sc_def_file_settings as sc_def_file_settings_cls
from .settings import settings as settings_cls
from .abaqus import abaqus as abaqus_cls
from .mechanical_apdl import mechanical_apdl as mechanical_apdl_cls
from .mechanical_apdl_input import mechanical_apdl_input as mechanical_apdl_input_cls
from .ascii import ascii as ascii_cls
from .avs import avs as avs_cls
from .ensight import ensight as ensight_cls
from .ensight_gold import ensight_gold as ensight_gold_cls
from .fieldview import fieldview as fieldview_cls
from .fieldview_data import fieldview_data as fieldview_data_cls
from .gambit import gambit as gambit_cls
from .cgns import cgns as cgns_cls
from .custom_heat_flux import custom_heat_flux as custom_heat_flux_cls
from .dx import dx as dx_cls
from .ensight_gold_parallel_surfaces import ensight_gold_parallel_surfaces as ensight_gold_parallel_surfaces_cls
from .ensight_gold_parallel_volume import ensight_gold_parallel_volume as ensight_gold_parallel_volume_cls
from .icemcfd_for_icepak import icemcfd_for_icepak as icemcfd_for_icepak_cls
from .fast_mesh import fast_mesh as fast_mesh_cls
from .fast_solution import fast_solution as fast_solution_cls
from .fast_velocity import fast_velocity as fast_velocity_cls
from .taitherm import taitherm as taitherm_cls
from .fieldview_unstruct import fieldview_unstruct as fieldview_unstruct_cls
from .fieldview_unstruct_mesh import fieldview_unstruct_mesh as fieldview_unstruct_mesh_cls
from .fieldview_unstruct_data import fieldview_unstruct_data as fieldview_unstruct_data_cls
from .fieldview_unstruct_surfaces import fieldview_unstruct_surfaces as fieldview_unstruct_surfaces_cls
from .ideas import ideas as ideas_cls
from .nastran import nastran as nastran_cls
from .patran_neutral import patran_neutral as patran_neutral_cls
from .patran_nodal import patran_nodal as patran_nodal_cls
from .tecplot import tecplot as tecplot_cls
class export(Group):
    """
    Enter the export menu.
    """

    fluent_name = "export"

    child_names = \
        ['sc_def_file_settings', 'settings']

    sc_def_file_settings: sc_def_file_settings_cls = sc_def_file_settings_cls
    """
    sc_def_file_settings child of export.
    """
    settings: settings_cls = settings_cls
    """
    settings child of export.
    """
    command_names = \
        ['abaqus', 'mechanical_apdl', 'mechanical_apdl_input', 'ascii', 'avs',
         'ensight', 'ensight_gold', 'fieldview', 'fieldview_data', 'gambit',
         'cgns', 'custom_heat_flux', 'dx', 'ensight_gold_parallel_surfaces',
         'ensight_gold_parallel_volume', 'icemcfd_for_icepak', 'fast_mesh',
         'fast_solution', 'fast_velocity', 'taitherm', 'fieldview_unstruct',
         'fieldview_unstruct_mesh', 'fieldview_unstruct_data',
         'fieldview_unstruct_surfaces', 'ideas', 'nastran', 'patran_neutral',
         'patran_nodal', 'tecplot']

    abaqus: abaqus_cls = abaqus_cls
    """
    abaqus command of export.
    """
    mechanical_apdl: mechanical_apdl_cls = mechanical_apdl_cls
    """
    mechanical_apdl command of export.
    """
    mechanical_apdl_input: mechanical_apdl_input_cls = mechanical_apdl_input_cls
    """
    mechanical_apdl_input command of export.
    """
    ascii: ascii_cls = ascii_cls
    """
    ascii command of export.
    """
    avs: avs_cls = avs_cls
    """
    avs command of export.
    """
    ensight: ensight_cls = ensight_cls
    """
    ensight command of export.
    """
    ensight_gold: ensight_gold_cls = ensight_gold_cls
    """
    ensight_gold command of export.
    """
    fieldview: fieldview_cls = fieldview_cls
    """
    fieldview command of export.
    """
    fieldview_data: fieldview_data_cls = fieldview_data_cls
    """
    fieldview_data command of export.
    """
    gambit: gambit_cls = gambit_cls
    """
    gambit command of export.
    """
    cgns: cgns_cls = cgns_cls
    """
    cgns command of export.
    """
    custom_heat_flux: custom_heat_flux_cls = custom_heat_flux_cls
    """
    custom_heat_flux command of export.
    """
    dx: dx_cls = dx_cls
    """
    dx command of export.
    """
    ensight_gold_parallel_surfaces: ensight_gold_parallel_surfaces_cls = ensight_gold_parallel_surfaces_cls
    """
    ensight_gold_parallel_surfaces command of export.
    """
    ensight_gold_parallel_volume: ensight_gold_parallel_volume_cls = ensight_gold_parallel_volume_cls
    """
    ensight_gold_parallel_volume command of export.
    """
    icemcfd_for_icepak: icemcfd_for_icepak_cls = icemcfd_for_icepak_cls
    """
    icemcfd_for_icepak command of export.
    """
    fast_mesh: fast_mesh_cls = fast_mesh_cls
    """
    fast_mesh command of export.
    """
    fast_solution: fast_solution_cls = fast_solution_cls
    """
    fast_solution command of export.
    """
    fast_velocity: fast_velocity_cls = fast_velocity_cls
    """
    fast_velocity command of export.
    """
    taitherm: taitherm_cls = taitherm_cls
    """
    taitherm command of export.
    """
    fieldview_unstruct: fieldview_unstruct_cls = fieldview_unstruct_cls
    """
    fieldview_unstruct command of export.
    """
    fieldview_unstruct_mesh: fieldview_unstruct_mesh_cls = fieldview_unstruct_mesh_cls
    """
    fieldview_unstruct_mesh command of export.
    """
    fieldview_unstruct_data: fieldview_unstruct_data_cls = fieldview_unstruct_data_cls
    """
    fieldview_unstruct_data command of export.
    """
    fieldview_unstruct_surfaces: fieldview_unstruct_surfaces_cls = fieldview_unstruct_surfaces_cls
    """
    fieldview_unstruct_surfaces command of export.
    """
    ideas: ideas_cls = ideas_cls
    """
    ideas command of export.
    """
    nastran: nastran_cls = nastran_cls
    """
    nastran command of export.
    """
    patran_neutral: patran_neutral_cls = patran_neutral_cls
    """
    patran_neutral command of export.
    """
    patran_nodal: patran_nodal_cls = patran_nodal_cls
    """
    patran_nodal command of export.
    """
    tecplot: tecplot_cls = tecplot_cls
    """
    tecplot command of export.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .refinement_criteria import refinement_criteria as refinement_criteria_cls
from .coarsening_criteria import coarsening_criteria as coarsening_criteria_cls
from .manual_refinement_criteria import manual_refinement_criteria as manual_refinement_criteria_cls
from .manual_coarsening_criteria import manual_coarsening_criteria as manual_coarsening_criteria_cls
from .set import set as set_cls
from .profile import profile as profile_cls
from .free_hierarchy import free_hierarchy as free_hierarchy_cls
from .multi_layer_refinement import multi_layer_refinement as multi_layer_refinement_cls
from .geometry import geometry as geometry_cls
from .adapt_mesh import adapt_mesh as adapt_mesh_cls
from .display_adaption_cells import display_adaption_cells as display_adaption_cells_cls
from .list_adaption_cells import list_adaption_cells as list_adaption_cells_cls
class adapt(Group):
    """
    'adapt' child.
    """

    fluent_name = "adapt"

    child_names = \
        ['refinement_criteria', 'coarsening_criteria',
         'manual_refinement_criteria', 'manual_coarsening_criteria', 'set',
         'profile', 'free_hierarchy', 'multi_layer_refinement', 'geometry']

    refinement_criteria: refinement_criteria_cls = refinement_criteria_cls
    """
    refinement_criteria child of adapt.
    """
    coarsening_criteria: coarsening_criteria_cls = coarsening_criteria_cls
    """
    coarsening_criteria child of adapt.
    """
    manual_refinement_criteria: manual_refinement_criteria_cls = manual_refinement_criteria_cls
    """
    manual_refinement_criteria child of adapt.
    """
    manual_coarsening_criteria: manual_coarsening_criteria_cls = manual_coarsening_criteria_cls
    """
    manual_coarsening_criteria child of adapt.
    """
    set: set_cls = set_cls
    """
    set child of adapt.
    """
    profile: profile_cls = profile_cls
    """
    profile child of adapt.
    """
    free_hierarchy: free_hierarchy_cls = free_hierarchy_cls
    """
    free_hierarchy child of adapt.
    """
    multi_layer_refinement: multi_layer_refinement_cls = multi_layer_refinement_cls
    """
    multi_layer_refinement child of adapt.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of adapt.
    """
    command_names = \
        ['adapt_mesh', 'display_adaption_cells', 'list_adaption_cells']

    adapt_mesh: adapt_mesh_cls = adapt_mesh_cls
    """
    adapt_mesh command of adapt.
    """
    display_adaption_cells: display_adaption_cells_cls = display_adaption_cells_cls
    """
    display_adaption_cells command of adapt.
    """
    list_adaption_cells: list_adaption_cells_cls = list_adaption_cells_cls
    """
    list_adaption_cells command of adapt.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .species import species as species_cls
from .reactions import reactions as reactions_cls
from .reaction_mechs import reaction_mechs as reaction_mechs_cls
from .density import density as density_cls
from .specific_heat import specific_heat as specific_heat_cls
from .thermal_conductivity import thermal_conductivity as thermal_conductivity_cls
from .viscosity import viscosity as viscosity_cls
from .molecular_weight import molecular_weight as molecular_weight_cls
from .mass_diffusivity import mass_diffusivity as mass_diffusivity_cls
from .thermal_diffusivity import thermal_diffusivity as thermal_diffusivity_cls
from .formation_enthalpy import formation_enthalpy as formation_enthalpy_cls
from .formation_entropy import formation_entropy as formation_entropy_cls
from .characteristic_vibrational_temperature import characteristic_vibrational_temperature as characteristic_vibrational_temperature_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .lennard_jones_length import lennard_jones_length as lennard_jones_length_cls
from .lennard_jones_energy import lennard_jones_energy as lennard_jones_energy_cls
from .thermal_accom_coefficient import thermal_accom_coefficient as thermal_accom_coefficient_cls
from .velocity_accom_coefficient import velocity_accom_coefficient as velocity_accom_coefficient_cls
from .absorption_coefficient import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .premix_unburnt_density import premix_unburnt_density as premix_unburnt_density_cls
from .premix_unburnt_temp import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_adiabatic_temp import premix_adiabatic_temp as premix_adiabatic_temp_cls
from .premix_unburnt_cp import premix_unburnt_cp as premix_unburnt_cp_cls
from .premix_heat_trans_coeff import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_laminar_thickness import premix_laminar_thickness as premix_laminar_thickness_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .premix_heat_of_comb import premix_heat_of_comb as premix_heat_of_comb_cls
from .premix_unburnt_fuel_mf import premix_unburnt_fuel_mf as premix_unburnt_fuel_mf_cls
from .refractive_index import refractive_index as refractive_index_cls
from .latent_heat import latent_heat as latent_heat_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .boiling_point import boiling_point as boiling_point_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .binary_diffusivity import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .vapor_pressure import vapor_pressure as vapor_pressure_cls
from .degrees_of_freedom import degrees_of_freedom as degrees_of_freedom_cls
from .emissivity import emissivity as emissivity_cls
from .scattering_factor import scattering_factor as scattering_factor_cls
from .heat_of_pyrolysis import heat_of_pyrolysis as heat_of_pyrolysis_cls
from .swelling_coefficient import swelling_coefficient as swelling_coefficient_cls
from .burn_stoichiometry import burn_stoichiometry as burn_stoichiometry_cls
from .combustible_fraction import combustible_fraction as combustible_fraction_cls
from .burn_hreact import burn_hreact as burn_hreact_cls
from .burn_hreact_fraction import burn_hreact_fraction as burn_hreact_fraction_cls
from .devolatilization_model import devolatilization_model as devolatilization_model_cls
from .combustion_model import combustion_model as combustion_model_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .thermolysis_model import thermolysis_model as thermolysis_model_cls
from .melting_heat import melting_heat as melting_heat_cls
from .tsolidus import tsolidus as tsolidus_cls
from .tliqidus import tliqidus as tliqidus_cls
from .tmelt import tmelt as tmelt_cls
from .liquidus_slope import liquidus_slope as liquidus_slope_cls
from .partition_coeff import partition_coeff as partition_coeff_cls
from .eutectic_mf import eutectic_mf as eutectic_mf_cls
from .eutectic_temp import eutectic_temp as eutectic_temp_cls
from .solut_exp_coeff import solut_exp_coeff as solut_exp_coeff_cls
from .solid_diffusion import solid_diffusion as solid_diffusion_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls
from .charge import charge as charge_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .species_phase import species_phase as species_phase_cls
from .vp_equilib import vp_equilib as vp_equilib_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .saturation_pressure import saturation_pressure as saturation_pressure_cls
from .struct_youngs_modulus import struct_youngs_modulus as struct_youngs_modulus_cls
from .struct_poisson_ratio import struct_poisson_ratio as struct_poisson_ratio_cls
from .struct_start_temperature import struct_start_temperature as struct_start_temperature_cls
from .struct_thermal_expansion import struct_thermal_expansion as struct_thermal_expansion_cls
from .atomic_number import atomic_number as atomic_number_cls
from .struct_damping_alpha import struct_damping_alpha as struct_damping_alpha_cls
from .struct_damping_beta import struct_damping_beta as struct_damping_beta_cls
from .mixture_species import mixture_species as mixture_species_cls
class mixture_child(Group):
    """
    'child_object_type' of mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['species', 'reactions', 'reaction_mechs', 'density', 'specific_heat',
         'thermal_conductivity', 'viscosity', 'molecular_weight',
         'mass_diffusivity', 'thermal_diffusivity', 'formation_enthalpy',
         'formation_entropy', 'characteristic_vibrational_temperature',
         'reference_temperature', 'lennard_jones_length',
         'lennard_jones_energy', 'thermal_accom_coefficient',
         'velocity_accom_coefficient', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'therm_exp_coeff', 'premix_unburnt_density', 'premix_unburnt_temp',
         'premix_adiabatic_temp', 'premix_unburnt_cp',
         'premix_heat_trans_coeff', 'premix_laminar_speed',
         'premix_laminar_thickness', 'premix_critical_strain',
         'premix_heat_of_comb', 'premix_unburnt_fuel_mf', 'refractive_index',
         'latent_heat', 'thermophoretic_co', 'vaporization_temperature',
         'boiling_point', 'volatile_fraction', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'vapor_pressure',
         'degrees_of_freedom', 'emissivity', 'scattering_factor',
         'heat_of_pyrolysis', 'swelling_coefficient', 'burn_stoichiometry',
         'combustible_fraction', 'burn_hreact', 'burn_hreact_fraction',
         'devolatilization_model', 'combustion_model',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vaporization_model', 'thermolysis_model', 'melting_heat',
         'tsolidus', 'tliqidus', 'tmelt', 'liquidus_slope', 'partition_coeff',
         'eutectic_mf', 'eutectic_temp', 'solut_exp_coeff', 'solid_diffusion',
         'uds_diffusivity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'charge_density', 'charge',
         'speed_of_sound', 'species_phase', 'vp_equilib',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'saturation_pressure', 'struct_youngs_modulus',
         'struct_poisson_ratio', 'struct_start_temperature',
         'struct_thermal_expansion', 'atomic_number', 'struct_damping_alpha',
         'struct_damping_beta', 'mixture_species']

    species: species_cls = species_cls
    """
    species child of mixture_child.
    """
    reactions: reactions_cls = reactions_cls
    """
    reactions child of mixture_child.
    """
    reaction_mechs: reaction_mechs_cls = reaction_mechs_cls
    """
    reaction_mechs child of mixture_child.
    """
    density: density_cls = density_cls
    """
    density child of mixture_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of mixture_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of mixture_child.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of mixture_child.
    """
    molecular_weight: molecular_weight_cls = molecular_weight_cls
    """
    molecular_weight child of mixture_child.
    """
    mass_diffusivity: mass_diffusivity_cls = mass_diffusivity_cls
    """
    mass_diffusivity child of mixture_child.
    """
    thermal_diffusivity: thermal_diffusivity_cls = thermal_diffusivity_cls
    """
    thermal_diffusivity child of mixture_child.
    """
    formation_enthalpy: formation_enthalpy_cls = formation_enthalpy_cls
    """
    formation_enthalpy child of mixture_child.
    """
    formation_entropy: formation_entropy_cls = formation_entropy_cls
    """
    formation_entropy child of mixture_child.
    """
    characteristic_vibrational_temperature: characteristic_vibrational_temperature_cls = characteristic_vibrational_temperature_cls
    """
    characteristic_vibrational_temperature child of mixture_child.
    """
    reference_temperature: reference_temperature_cls = reference_temperature_cls
    """
    reference_temperature child of mixture_child.
    """
    lennard_jones_length: lennard_jones_length_cls = lennard_jones_length_cls
    """
    lennard_jones_length child of mixture_child.
    """
    lennard_jones_energy: lennard_jones_energy_cls = lennard_jones_energy_cls
    """
    lennard_jones_energy child of mixture_child.
    """
    thermal_accom_coefficient: thermal_accom_coefficient_cls = thermal_accom_coefficient_cls
    """
    thermal_accom_coefficient child of mixture_child.
    """
    velocity_accom_coefficient: velocity_accom_coefficient_cls = velocity_accom_coefficient_cls
    """
    velocity_accom_coefficient child of mixture_child.
    """
    absorption_coefficient: absorption_coefficient_cls = absorption_coefficient_cls
    """
    absorption_coefficient child of mixture_child.
    """
    scattering_coefficient: scattering_coefficient_cls = scattering_coefficient_cls
    """
    scattering_coefficient child of mixture_child.
    """
    scattering_phase_function: scattering_phase_function_cls = scattering_phase_function_cls
    """
    scattering_phase_function child of mixture_child.
    """
    therm_exp_coeff: therm_exp_coeff_cls = therm_exp_coeff_cls
    """
    therm_exp_coeff child of mixture_child.
    """
    premix_unburnt_density: premix_unburnt_density_cls = premix_unburnt_density_cls
    """
    premix_unburnt_density child of mixture_child.
    """
    premix_unburnt_temp: premix_unburnt_temp_cls = premix_unburnt_temp_cls
    """
    premix_unburnt_temp child of mixture_child.
    """
    premix_adiabatic_temp: premix_adiabatic_temp_cls = premix_adiabatic_temp_cls
    """
    premix_adiabatic_temp child of mixture_child.
    """
    premix_unburnt_cp: premix_unburnt_cp_cls = premix_unburnt_cp_cls
    """
    premix_unburnt_cp child of mixture_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff_cls = premix_heat_trans_coeff_cls
    """
    premix_heat_trans_coeff child of mixture_child.
    """
    premix_laminar_speed: premix_laminar_speed_cls = premix_laminar_speed_cls
    """
    premix_laminar_speed child of mixture_child.
    """
    premix_laminar_thickness: premix_laminar_thickness_cls = premix_laminar_thickness_cls
    """
    premix_laminar_thickness child of mixture_child.
    """
    premix_critical_strain: premix_critical_strain_cls = premix_critical_strain_cls
    """
    premix_critical_strain child of mixture_child.
    """
    premix_heat_of_comb: premix_heat_of_comb_cls = premix_heat_of_comb_cls
    """
    premix_heat_of_comb child of mixture_child.
    """
    premix_unburnt_fuel_mf: premix_unburnt_fuel_mf_cls = premix_unburnt_fuel_mf_cls
    """
    premix_unburnt_fuel_mf child of mixture_child.
    """
    refractive_index: refractive_index_cls = refractive_index_cls
    """
    refractive_index child of mixture_child.
    """
    latent_heat: latent_heat_cls = latent_heat_cls
    """
    latent_heat child of mixture_child.
    """
    thermophoretic_co: thermophoretic_co_cls = thermophoretic_co_cls
    """
    thermophoretic_co child of mixture_child.
    """
    vaporization_temperature: vaporization_temperature_cls = vaporization_temperature_cls
    """
    vaporization_temperature child of mixture_child.
    """
    boiling_point: boiling_point_cls = boiling_point_cls
    """
    boiling_point child of mixture_child.
    """
    volatile_fraction: volatile_fraction_cls = volatile_fraction_cls
    """
    volatile_fraction child of mixture_child.
    """
    binary_diffusivity: binary_diffusivity_cls = binary_diffusivity_cls
    """
    binary_diffusivity child of mixture_child.
    """
    diffusivity_reference_pressure: diffusivity_reference_pressure_cls = diffusivity_reference_pressure_cls
    """
    diffusivity_reference_pressure child of mixture_child.
    """
    vapor_pressure: vapor_pressure_cls = vapor_pressure_cls
    """
    vapor_pressure child of mixture_child.
    """
    degrees_of_freedom: degrees_of_freedom_cls = degrees_of_freedom_cls
    """
    degrees_of_freedom child of mixture_child.
    """
    emissivity: emissivity_cls = emissivity_cls
    """
    emissivity child of mixture_child.
    """
    scattering_factor: scattering_factor_cls = scattering_factor_cls
    """
    scattering_factor child of mixture_child.
    """
    heat_of_pyrolysis: heat_of_pyrolysis_cls = heat_of_pyrolysis_cls
    """
    heat_of_pyrolysis child of mixture_child.
    """
    swelling_coefficient: swelling_coefficient_cls = swelling_coefficient_cls
    """
    swelling_coefficient child of mixture_child.
    """
    burn_stoichiometry: burn_stoichiometry_cls = burn_stoichiometry_cls
    """
    burn_stoichiometry child of mixture_child.
    """
    combustible_fraction: combustible_fraction_cls = combustible_fraction_cls
    """
    combustible_fraction child of mixture_child.
    """
    burn_hreact: burn_hreact_cls = burn_hreact_cls
    """
    burn_hreact child of mixture_child.
    """
    burn_hreact_fraction: burn_hreact_fraction_cls = burn_hreact_fraction_cls
    """
    burn_hreact_fraction child of mixture_child.
    """
    devolatilization_model: devolatilization_model_cls = devolatilization_model_cls
    """
    devolatilization_model child of mixture_child.
    """
    combustion_model: combustion_model_cls = combustion_model_cls
    """
    combustion_model child of mixture_child.
    """
    averaging_coefficient_t: averaging_coefficient_t_cls = averaging_coefficient_t_cls
    """
    averaging_coefficient_t child of mixture_child.
    """
    averaging_coefficient_y: averaging_coefficient_y_cls = averaging_coefficient_y_cls
    """
    averaging_coefficient_y child of mixture_child.
    """
    vaporization_model: vaporization_model_cls = vaporization_model_cls
    """
    vaporization_model child of mixture_child.
    """
    thermolysis_model: thermolysis_model_cls = thermolysis_model_cls
    """
    thermolysis_model child of mixture_child.
    """
    melting_heat: melting_heat_cls = melting_heat_cls
    """
    melting_heat child of mixture_child.
    """
    tsolidus: tsolidus_cls = tsolidus_cls
    """
    tsolidus child of mixture_child.
    """
    tliqidus: tliqidus_cls = tliqidus_cls
    """
    tliqidus child of mixture_child.
    """
    tmelt: tmelt_cls = tmelt_cls
    """
    tmelt child of mixture_child.
    """
    liquidus_slope: liquidus_slope_cls = liquidus_slope_cls
    """
    liquidus_slope child of mixture_child.
    """
    partition_coeff: partition_coeff_cls = partition_coeff_cls
    """
    partition_coeff child of mixture_child.
    """
    eutectic_mf: eutectic_mf_cls = eutectic_mf_cls
    """
    eutectic_mf child of mixture_child.
    """
    eutectic_temp: eutectic_temp_cls = eutectic_temp_cls
    """
    eutectic_temp child of mixture_child.
    """
    solut_exp_coeff: solut_exp_coeff_cls = solut_exp_coeff_cls
    """
    solut_exp_coeff child of mixture_child.
    """
    solid_diffusion: solid_diffusion_cls = solid_diffusion_cls
    """
    solid_diffusion child of mixture_child.
    """
    uds_diffusivity: uds_diffusivity_cls = uds_diffusivity_cls
    """
    uds_diffusivity child of mixture_child.
    """
    dpm_surften: dpm_surften_cls = dpm_surften_cls
    """
    dpm_surften child of mixture_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of mixture_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of mixture_child.
    """
    lithium_diffusivity: lithium_diffusivity_cls = lithium_diffusivity_cls
    """
    lithium_diffusivity child of mixture_child.
    """
    magnetic_permeability: magnetic_permeability_cls = magnetic_permeability_cls
    """
    magnetic_permeability child of mixture_child.
    """
    charge_density: charge_density_cls = charge_density_cls
    """
    charge_density child of mixture_child.
    """
    charge: charge_cls = charge_cls
    """
    charge child of mixture_child.
    """
    speed_of_sound: speed_of_sound_cls = speed_of_sound_cls
    """
    speed_of_sound child of mixture_child.
    """
    species_phase: species_phase_cls = species_phase_cls
    """
    species_phase child of mixture_child.
    """
    vp_equilib: vp_equilib_cls = vp_equilib_cls
    """
    vp_equilib child of mixture_child.
    """
    critical_temperature: critical_temperature_cls = critical_temperature_cls
    """
    critical_temperature child of mixture_child.
    """
    critical_pressure: critical_pressure_cls = critical_pressure_cls
    """
    critical_pressure child of mixture_child.
    """
    critical_volume: critical_volume_cls = critical_volume_cls
    """
    critical_volume child of mixture_child.
    """
    acentric_factor: acentric_factor_cls = acentric_factor_cls
    """
    acentric_factor child of mixture_child.
    """
    saturation_pressure: saturation_pressure_cls = saturation_pressure_cls
    """
    saturation_pressure child of mixture_child.
    """
    struct_youngs_modulus: struct_youngs_modulus_cls = struct_youngs_modulus_cls
    """
    struct_youngs_modulus child of mixture_child.
    """
    struct_poisson_ratio: struct_poisson_ratio_cls = struct_poisson_ratio_cls
    """
    struct_poisson_ratio child of mixture_child.
    """
    struct_start_temperature: struct_start_temperature_cls = struct_start_temperature_cls
    """
    struct_start_temperature child of mixture_child.
    """
    struct_thermal_expansion: struct_thermal_expansion_cls = struct_thermal_expansion_cls
    """
    struct_thermal_expansion child of mixture_child.
    """
    atomic_number: atomic_number_cls = atomic_number_cls
    """
    atomic_number child of mixture_child.
    """
    struct_damping_alpha: struct_damping_alpha_cls = struct_damping_alpha_cls
    """
    struct_damping_alpha child of mixture_child.
    """
    struct_damping_beta: struct_damping_beta_cls = struct_damping_beta_cls
    """
    struct_damping_beta child of mixture_child.
    """
    mixture_species: mixture_species_cls = mixture_species_cls
    """
    mixture_species child of mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .create_1 import create_1 as create_1_cls
from .duplicate_1 import duplicate as duplicate_cls
from .load_case_data import load_case_data as load_case_data_cls
from .delete_design_points import delete_design_points as delete_design_points_cls
from .save_journals import save_journals as save_journals_cls
from .clear_generated_data import clear_generated_data as clear_generated_data_cls
from .update_current import update_current as update_current_cls
from .update_all import update_all as update_all_cls
from .update_selected import update_selected as update_selected_cls
from .design_points_child import design_points_child

class design_points(NamedObject[design_points_child], _CreatableNamedObjectMixin[design_points_child]):
    """
    'design_points' child.
    """

    fluent_name = "design-points"

    command_names = \
        ['create_1', 'duplicate', 'load_case_data', 'delete_design_points',
         'save_journals', 'clear_generated_data', 'update_current',
         'update_all', 'update_selected']

    create_1: create_1_cls = create_1_cls
    """
    create_1 command of design_points.
    """
    duplicate: duplicate_cls = duplicate_cls
    """
    duplicate command of design_points.
    """
    load_case_data: load_case_data_cls = load_case_data_cls
    """
    load_case_data command of design_points.
    """
    delete_design_points: delete_design_points_cls = delete_design_points_cls
    """
    delete_design_points command of design_points.
    """
    save_journals: save_journals_cls = save_journals_cls
    """
    save_journals command of design_points.
    """
    clear_generated_data: clear_generated_data_cls = clear_generated_data_cls
    """
    clear_generated_data command of design_points.
    """
    update_current: update_current_cls = update_current_cls
    """
    update_current command of design_points.
    """
    update_all: update_all_cls = update_all_cls
    """
    update_all command of design_points.
    """
    update_selected: update_selected_cls = update_selected_cls
    """
    update_selected command of design_points.
    """
    child_object_type: design_points_child = design_points_child
    """
    child_object_type of design_points.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .write_summary_to_file import write_summary_to_file as write_summary_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .include_in_domains_particles import include_in_domains_particles as include_in_domains_particles_cls
from .pick_injection import pick_injection as pick_injection_cls
from .injection_1 import injection as injection_cls
class extended_summary(Command):
    """
    Print extended discrete phase summary report of particle fates, with options.
    
    Parameters
    ----------
        write_summary_to_file : bool
            'write_summary_to_file' child.
        file_name : str
            'file_name' child.
        include_in_domains_particles : bool
            'include_in_domains_particles' child.
        pick_injection : bool
            'pick_injection' child.
        injection : str
            'injection' child.
    
    """

    fluent_name = "extended-summary"

    argument_names = \
        ['write_summary_to_file', 'file_name', 'include_in_domains_particles',
         'pick_injection', 'injection']

    write_summary_to_file: write_summary_to_file_cls = write_summary_to_file_cls
    """
    write_summary_to_file argument of extended_summary.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of extended_summary.
    """
    include_in_domains_particles: include_in_domains_particles_cls = include_in_domains_particles_cls
    """
    include_in_domains_particles argument of extended_summary.
    """
    pick_injection: pick_injection_cls = pick_injection_cls
    """
    pick_injection argument of extended_summary.
    """
    injection: injection_cls = injection_cls
    """
    injection argument of extended_summary.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .surface_name_list import surface_name_list as surface_name_list_cls
from .structural_analysis import structural_analysis as structural_analysis_cls
from .write_loads import write_loads as write_loads_cls
from .loads import loads as loads_cls
class abaqus(Command):
    """
    Write an ABAQUS file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surface_name_list : typing.List[str]
            'surface_name_list' child.
        structural_analysis : bool
            'structural_analysis' child.
        write_loads : bool
            'write_loads' child.
        loads : typing.List[str]
            'loads' child.
    
    """

    fluent_name = "abaqus"

    argument_names = \
        ['name', 'surface_name_list', 'structural_analysis', 'write_loads',
         'loads']

    name: name_cls = name_cls
    """
    name argument of abaqus.
    """
    surface_name_list: surface_name_list_cls = surface_name_list_cls
    """
    surface_name_list argument of abaqus.
    """
    structural_analysis: structural_analysis_cls = structural_analysis_cls
    """
    structural_analysis argument of abaqus.
    """
    write_loads: write_loads_cls = write_loads_cls
    """
    write_loads argument of abaqus.
    """
    loads: loads_cls = loads_cls
    """
    loads argument of abaqus.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .all import all as all_cls
from .feature import feature as feature_cls
from .outline import outline as outline_cls
class edge_type(Group):
    """
    'edge_type' child.
    """

    fluent_name = "edge-type"

    child_names = \
        ['option', 'all', 'feature', 'outline']

    option: option_cls = option_cls
    """
    option child of edge_type.
    """
    all: all_cls = all_cls
    """
    all child of edge_type.
    """
    feature: feature_cls = feature_cls
    """
    feature child of edge_type.
    """
    outline: outline_cls = outline_cls
    """
    outline child of edge_type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .low_re_ke import low_re_ke as low_re_ke_cls
from .low_re_ke_index import low_re_ke_index as low_re_ke_index_cls
from .kato_launder_model import kato_launder_model as kato_launder_model_cls
from .production_limiter import production_limiter as production_limiter_cls
from .kw_vorticity_based_production import kw_vorticity_based_production as kw_vorticity_based_production_cls
from .kw_add_sas import kw_add_sas as kw_add_sas_cls
from .kw_add_des import kw_add_des as kw_add_des_cls
from .turb_add_sbes_sdes import turb_add_sbes_sdes as turb_add_sbes_sdes_cls
from .sbes_sdes_hybrid_model import sbes_sdes_hybrid_model as sbes_sdes_hybrid_model_cls
from .sbes_update_interval_k_omega import sbes_update_interval_k_omega as sbes_update_interval_k_omega_cls
from .sbes_sgs_option import sbes_sgs_option as sbes_sgs_option_cls
from .sbes_les_subgrid_dynamic_fvar import sbes_les_subgrid_dynamic_fvar as sbes_les_subgrid_dynamic_fvar_cls
from .turbulence_damping import turbulence_damping as turbulence_damping_cls
from .rke_cmu_rotation_term import rke_cmu_rotation_term as rke_cmu_rotation_term_cls
from .turb_non_newtonian import turb_non_newtonian as turb_non_newtonian_cls
from .non_newtonian_modification import non_newtonian_modification as non_newtonian_modification_cls
from .turb_pk_compressible import turb_pk_compressible as turb_pk_compressible_cls
from .thermal_p_function import thermal_p_function as thermal_p_function_cls
from .restore_sst_v61 import restore_sst_v61 as restore_sst_v61_cls
class turbulence_expert(Group):
    """
    'turbulence_expert' child.
    """

    fluent_name = "turbulence-expert"

    child_names = \
        ['low_re_ke', 'low_re_ke_index', 'kato_launder_model',
         'production_limiter', 'kw_vorticity_based_production', 'kw_add_sas',
         'kw_add_des', 'turb_add_sbes_sdes', 'sbes_sdes_hybrid_model',
         'sbes_update_interval_k_omega', 'sbes_sgs_option',
         'sbes_les_subgrid_dynamic_fvar', 'turbulence_damping',
         'rke_cmu_rotation_term', 'turb_non_newtonian',
         'non_newtonian_modification', 'turb_pk_compressible',
         'thermal_p_function', 'restore_sst_v61']

    low_re_ke: low_re_ke_cls = low_re_ke_cls
    """
    low_re_ke child of turbulence_expert.
    """
    low_re_ke_index: low_re_ke_index_cls = low_re_ke_index_cls
    """
    low_re_ke_index child of turbulence_expert.
    """
    kato_launder_model: kato_launder_model_cls = kato_launder_model_cls
    """
    kato_launder_model child of turbulence_expert.
    """
    production_limiter: production_limiter_cls = production_limiter_cls
    """
    production_limiter child of turbulence_expert.
    """
    kw_vorticity_based_production: kw_vorticity_based_production_cls = kw_vorticity_based_production_cls
    """
    kw_vorticity_based_production child of turbulence_expert.
    """
    kw_add_sas: kw_add_sas_cls = kw_add_sas_cls
    """
    kw_add_sas child of turbulence_expert.
    """
    kw_add_des: kw_add_des_cls = kw_add_des_cls
    """
    kw_add_des child of turbulence_expert.
    """
    turb_add_sbes_sdes: turb_add_sbes_sdes_cls = turb_add_sbes_sdes_cls
    """
    turb_add_sbes_sdes child of turbulence_expert.
    """
    sbes_sdes_hybrid_model: sbes_sdes_hybrid_model_cls = sbes_sdes_hybrid_model_cls
    """
    sbes_sdes_hybrid_model child of turbulence_expert.
    """
    sbes_update_interval_k_omega: sbes_update_interval_k_omega_cls = sbes_update_interval_k_omega_cls
    """
    sbes_update_interval_k_omega child of turbulence_expert.
    """
    sbes_sgs_option: sbes_sgs_option_cls = sbes_sgs_option_cls
    """
    sbes_sgs_option child of turbulence_expert.
    """
    sbes_les_subgrid_dynamic_fvar: sbes_les_subgrid_dynamic_fvar_cls = sbes_les_subgrid_dynamic_fvar_cls
    """
    sbes_les_subgrid_dynamic_fvar child of turbulence_expert.
    """
    turbulence_damping: turbulence_damping_cls = turbulence_damping_cls
    """
    turbulence_damping child of turbulence_expert.
    """
    rke_cmu_rotation_term: rke_cmu_rotation_term_cls = rke_cmu_rotation_term_cls
    """
    rke_cmu_rotation_term child of turbulence_expert.
    """
    turb_non_newtonian: turb_non_newtonian_cls = turb_non_newtonian_cls
    """
    turb_non_newtonian child of turbulence_expert.
    """
    non_newtonian_modification: non_newtonian_modification_cls = non_newtonian_modification_cls
    """
    non_newtonian_modification child of turbulence_expert.
    """
    turb_pk_compressible: turb_pk_compressible_cls = turb_pk_compressible_cls
    """
    turb_pk_compressible child of turbulence_expert.
    """
    thermal_p_function: thermal_p_function_cls = thermal_p_function_cls
    """
    thermal_p_function child of turbulence_expert.
    """
    restore_sst_v61: restore_sst_v61_cls = restore_sst_v61_cls
    """
    restore_sst_v61 child of turbulence_expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class real_gas_state(String, _HasAllowedValuesMixin):
    """
    Select state for real gas EOS subcritical condition.
    """

    fluent_name = "real-gas-state"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .list_valid_report_names import list_valid_report_names as list_valid_report_names_cls
from .define import define as define_cls
from .average_over import average_over as average_over_cls
from .old_props import old_props as old_props_cls
class single_val_expression_child(Group):
    """
    'child_object_type' of single_val_expression.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'retain_instantaneous_values', 'list_valid_report_names',
         'define', 'average_over', 'old_props']

    name: name_cls = name_cls
    """
    name child of single_val_expression_child.
    """
    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of single_val_expression_child.
    """
    list_valid_report_names: list_valid_report_names_cls = list_valid_report_names_cls
    """
    list_valid_report_names child of single_val_expression_child.
    """
    define: define_cls = define_cls
    """
    define child of single_val_expression_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of single_val_expression_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of single_val_expression_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_5 import enable as enable_cls
from .turbulent_approximation import turbulent_approximation as turbulent_approximation_cls
class convective_heat_transfer(Group):
    """
    'convective_heat_transfer' child.
    """

    fluent_name = "convective-heat-transfer"

    child_names = \
        ['enable', 'turbulent_approximation']

    enable: enable_cls = enable_cls
    """
    enable child of convective_heat_transfer.
    """
    turbulent_approximation: turbulent_approximation_cls = turbulent_approximation_cls
    """
    turbulent_approximation child of convective_heat_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class initialization:
    fluent_name = ...
    child_names = ...
    initialization_type = ...
    reference_frame = ...
    defaults = ...
    fmg_options = ...
    localized_turb_init = ...
    hybrid_init_options = ...
    patch = ...
    open_channel_auto_init = ...
    fmg_initialization = ...
    command_names = ...

    def initialize(self, ):
        """
        'initialize' command.
        """

    def compute_defaults(self, from_zone_type: str, from_zone_name: str, phase: str):
        """
        'compute_defaults' command.
        
        Parameters
        ----------
            from_zone_type : str
                'from_zone_type' child.
            from_zone_name : str
                'from_zone_name' child.
            phase : str
                'phase' child.
        
        """

    def fmg_initialize(self, ):
        """
        Initialize using the full-multigrid initialization (FMG).
        """

    def standard_initialize(self, ):
        """
        Initialize the flow field with the current default values.
        """

    def hybrid_initialize(self, ):
        """
        Initialize using the hybrid initialization method.
        """

    def list_defaults(self, ):
        """
        List default values.
        """

    def init_turb_vel_fluctuations(self, ):
        """
        Initialize turbulent velocity fluctuations.
        """

    def init_flow_statistics(self, ):
        """
        Initialize statistics.
        """

    def show_iterations_sampled(self, ):
        """
        'show_iterations_sampled' command.
        """

    def show_time_sampled(self, ):
        """
        Display the amount of simulated time covered by the data sampled for unsteady statistics.
        """

    def dpm_reset(self, ):
        """
        Reset discrete phase source terms to zero.
        """

    def lwf_reset(self, ):
        """
        Delete wall film particles and initialize wall film variables to zero.
        """

    def init_acoustics_options(self, set_ramping_length: bool, time_step_count: int):
        """
        'init_acoustics_options' command.
        
        Parameters
        ----------
            set_ramping_length : bool
                Enable/Disable ramping length and initialize acoustics.
            time_step_count : int
                Set number of timesteps for ramping of sources.
        
        """

    def levelset_auto_init(self, ):
        """
        'levelset_auto_init' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .iso_surface_child import iso_surface_child

class iso_surface(NamedObject[iso_surface_child], _CreatableNamedObjectMixin[iso_surface_child]):
    """
    'iso_surface' child.
    """

    fluent_name = "iso-surface"

    command_names = \
        ['list', 'list_properties', 'duplicate']

    list: list_cls = list_cls
    """
    list command of iso_surface.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of iso_surface.
    """
    duplicate: duplicate_cls = duplicate_cls
    """
    duplicate command of iso_surface.
    """
    child_object_type: iso_surface_child = iso_surface_child
    """
    child_object_type of iso_surface.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .relaxation_factor_2 import relaxation_factor as relaxation_factor_cls
from .select_variables import select_variables as select_variables_cls
from .relaxation_options import relaxation_options as relaxation_options_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['relaxation_factor', 'select_variables', 'relaxation_options']

    relaxation_factor: relaxation_factor_cls = relaxation_factor_cls
    """
    relaxation_factor child of options.
    """
    select_variables: select_variables_cls = select_variables_cls
    """
    select_variables child of options.
    """
    relaxation_options: relaxation_options_cls = relaxation_options_cls
    """
    relaxation_options child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mesh_1 import mesh as mesh_cls
from .surface_1 import surface as surface_cls
from .volume import volume as volume_cls
from .force import force as force_cls
from .lift import lift as lift_cls
from .drag import drag as drag_cls
from .moment import moment as moment_cls
from .flux_1 import flux as flux_cls
from .injection import injection as injection_cls
from .user_defined_5 import user_defined as user_defined_cls
from .aeromechanics import aeromechanics as aeromechanics_cls
from .icing import icing as icing_cls
from .expression_1 import expression as expression_cls
from .single_val_expression import single_val_expression as single_val_expression_cls
from .custom import custom as custom_cls
from .compute_1 import compute as compute_cls
from .copy_2 import copy as copy_cls
from .list import list as list_cls
class report_definitions(Group, _ChildNamedObjectAccessorMixin):
    """
    'report_definitions' child.
    """

    fluent_name = "report-definitions"

    child_names = \
        ['mesh', 'surface', 'volume', 'force', 'lift', 'drag', 'moment',
         'flux', 'injection', 'user_defined', 'aeromechanics', 'icing',
         'expression', 'single_val_expression', 'custom']

    mesh: mesh_cls = mesh_cls
    """
    mesh child of report_definitions.
    """
    surface: surface_cls = surface_cls
    """
    surface child of report_definitions.
    """
    volume: volume_cls = volume_cls
    """
    volume child of report_definitions.
    """
    force: force_cls = force_cls
    """
    force child of report_definitions.
    """
    lift: lift_cls = lift_cls
    """
    lift child of report_definitions.
    """
    drag: drag_cls = drag_cls
    """
    drag child of report_definitions.
    """
    moment: moment_cls = moment_cls
    """
    moment child of report_definitions.
    """
    flux: flux_cls = flux_cls
    """
    flux child of report_definitions.
    """
    injection: injection_cls = injection_cls
    """
    injection child of report_definitions.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of report_definitions.
    """
    aeromechanics: aeromechanics_cls = aeromechanics_cls
    """
    aeromechanics child of report_definitions.
    """
    icing: icing_cls = icing_cls
    """
    icing child of report_definitions.
    """
    expression: expression_cls = expression_cls
    """
    expression child of report_definitions.
    """
    single_val_expression: single_val_expression_cls = single_val_expression_cls
    """
    single_val_expression child of report_definitions.
    """
    custom: custom_cls = custom_cls
    """
    custom child of report_definitions.
    """
    command_names = \
        ['compute', 'copy', 'list']

    compute: compute_cls = compute_cls
    """
    compute command of report_definitions.
    """
    copy: copy_cls = copy_cls
    """
    copy command of report_definitions.
    """
    list: list_cls = list_cls
    """
    list command of report_definitions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class statistics:
    fluent_name = ...
    child_names = ...
    reset_statistics = ...
    command_names = ...

    def statistics_controls(self, method: int, samp_time_period: Union[float, str], samp_time_steps: int, avg_time_period: Union[float, str], avg_time_steps: int):
        """
        'statistics_controls' command.
        
        Parameters
        ----------
            method : int
                'method' child.
            samp_time_period : real
                'samp_time_period' child.
            samp_time_steps : int
                'samp_time_steps' child.
            avg_time_period : real
                'avg_time_period' child.
            avg_time_steps : int
                'avg_time_steps' child.
        
        """




from ansys.fluent.core import examples
from ansys.fluent.core.filereader.case_file import CaseFile
from ansys.fluent.core.filereader.data_file import DataFile


def test_data_reader_for_single_phase():
    case_filename = examples.download_file(
        "elbow1.cas.h5", "pyfluent/file_session", return_only_filename=False
    )

    data_filename = examples.download_file(
        "elbow1.dat.h5", "pyfluent/file_session", return_only_filename=False
    )

    reader = DataFile(
        data_filepath=data_filename,
        case_file_handle=CaseFile(case_filepath=case_filename),
    )

    assert reader.case_file == "elbow1.cas.h5"

    assert len(reader.variables()) == 80

    assert reader.get_phases() == ["phase-1"]

    assert len(reader.get_face_variables("phase-1")) == 30

    assert len(reader.get_cell_variables("phase-1")) == 14

    assert reader.get_cell_variables("phase-1") == [
        "SV_BF_V",
        "SV_D",
        "SV_DENSITY",
        "SV_H",
        "SV_K",
        "SV_LORENTZ_FORCE",
        "SV_MU_LAM",
        "SV_MU_T",
        "SV_P",
        "SV_T",
        "SV_U",
        "SV_V",
        "SV_W",
        "",
    ]

    assert len(reader.get_face_scalar_field_data("phase-1", "SV_DENSITY", 3)) == 3630

    assert len(reader.get_face_vector_field_data("phase-1", 3)) == 10890


def test_data_reader_for_multi_phase():
    case_filename = examples.download_file(
        "mixing_elbow_mul_ph.cas.h5",
        "pyfluent/file_session",
        return_only_filename=False,
    )
    data_filename = examples.download_file(
        "mixing_elbow_mul_ph.dat.h5",
        "pyfluent/file_session",
        return_only_filename=False,
    )

    reader = DataFile(
        data_filepath=data_filename,
        case_file_handle=CaseFile(case_filepath=case_filename),
    )  # Instantiate a DataFile class

    assert reader.case_file == "mixing_elbow_mul_ph.cas.h5"

    assert len(reader.variables()) == 80

    assert reader.get_phases() == [
        "phase-1",
        "phase-2",
        "phase-3",
        "phase-4",
    ]

    assert len(reader.get_face_variables("phase-1")) == 23

    assert len(reader.get_face_variables("phase-3")) == 13

    assert len(reader.get_cell_variables("phase-2")) == 14

    assert reader.get_cell_variables("phase-2") == [
        "SV_BF_V",
        "SV_DENSITY",
        "SV_DENSITY_M1",
        "SV_MU_LAM",
        "SV_MU_T",
        "SV_U",
        "SV_U_M1",
        "SV_V",
        "SV_VOF",
        "SV_VOF_M1",
        "SV_V_M1",
        "SV_W",
        "SV_W_M1",
        "",
    ]

    assert len(reader.get_face_scalar_field_data("phase-1", "SV_DENSITY", 33)) == 268



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class disk_id:
    fluent_name = ...
    child_names = ...
    embedded_face_zone = ...
    floating_surface_name = ...
    command_names = ...

    def create_floating_disk(self, ):
        """
        'create_floating_disk' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .particle_species import particle_species as particle_species_cls
from .last_species import last_species as last_species_cls
class species(Group):
    """
    'species' child.
    """

    fluent_name = "species"

    child_names = \
        ['particle_species', 'last_species']

    particle_species: particle_species_cls = particle_species_cls
    """
    particle_species child of species.
    """
    last_species: last_species_cls = last_species_cls
    """
    last_species child of species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .p_v_coupling import p_v_coupling as p_v_coupling_cls
from .flux_type_2 import flux_type as flux_type_cls
from .discretization_scheme import discretization_scheme as discretization_scheme_cls
from .pseudo_time_method import pseudo_time_method as pseudo_time_method_cls
from .unsteady_1st_order import unsteady_1st_order as unsteady_1st_order_cls
from .unsteady_2nd_order import unsteady_2nd_order as unsteady_2nd_order_cls
from .unsteady_2nd_order_bounded import unsteady_2nd_order_bounded as unsteady_2nd_order_bounded_cls
from .unsteady_global_time import unsteady_global_time as unsteady_global_time_cls
from .accelerated_non_iterative_time_marching import accelerated_non_iterative_time_marching as accelerated_non_iterative_time_marching_cls
from .convergence_acceleration_for_stretched_meshes_1 import convergence_acceleration_for_stretched_meshes as convergence_acceleration_for_stretched_meshes_cls
from .expert_1 import expert as expert_cls
from .frozen_flux import frozen_flux as frozen_flux_cls
from .gradient_scheme import gradient_scheme as gradient_scheme_cls
from .high_order_term_relaxation import high_order_term_relaxation as high_order_term_relaxation_cls
from .multiphase_numerics import multiphase_numerics as multiphase_numerics_cls
from .nb_gradient_boundary_option import nb_gradient_boundary_option as nb_gradient_boundary_option_cls
from .nita import nita as nita_cls
from .nita_expert_controls import nita_expert_controls as nita_expert_controls_cls
from .overset_1 import overset as overset_cls
from .phase_based_vof_discretization import phase_based_vof_discretization as phase_based_vof_discretization_cls
from .reduced_rank_extrapolation import reduced_rank_extrapolation as reduced_rank_extrapolation_cls
from .reduced_rank_extrapolation_options import reduced_rank_extrapolation_options as reduced_rank_extrapolation_options_cls
from .residual_smoothing import residual_smoothing as residual_smoothing_cls
from .vof_numerics import vof_numerics as vof_numerics_cls
from .warped_face_gradient_correction import warped_face_gradient_correction as warped_face_gradient_correction_cls
from .set_solution_methods_to_default import set_solution_methods_to_default as set_solution_methods_to_default_cls
class methods(Group):
    """
    'methods' child.
    """

    fluent_name = "methods"

    child_names = \
        ['p_v_coupling', 'flux_type', 'discretization_scheme',
         'pseudo_time_method', 'unsteady_1st_order', 'unsteady_2nd_order',
         'unsteady_2nd_order_bounded', 'unsteady_global_time',
         'accelerated_non_iterative_time_marching',
         'convergence_acceleration_for_stretched_meshes', 'expert',
         'frozen_flux', 'gradient_scheme', 'high_order_term_relaxation',
         'multiphase_numerics', 'nb_gradient_boundary_option', 'nita',
         'nita_expert_controls', 'overset', 'phase_based_vof_discretization',
         'reduced_rank_extrapolation', 'reduced_rank_extrapolation_options',
         'residual_smoothing', 'vof_numerics',
         'warped_face_gradient_correction']

    p_v_coupling: p_v_coupling_cls = p_v_coupling_cls
    """
    p_v_coupling child of methods.
    """
    flux_type: flux_type_cls = flux_type_cls
    """
    flux_type child of methods.
    """
    discretization_scheme: discretization_scheme_cls = discretization_scheme_cls
    """
    discretization_scheme child of methods.
    """
    pseudo_time_method: pseudo_time_method_cls = pseudo_time_method_cls
    """
    pseudo_time_method child of methods.
    """
    unsteady_1st_order: unsteady_1st_order_cls = unsteady_1st_order_cls
    """
    unsteady_1st_order child of methods.
    """
    unsteady_2nd_order: unsteady_2nd_order_cls = unsteady_2nd_order_cls
    """
    unsteady_2nd_order child of methods.
    """
    unsteady_2nd_order_bounded: unsteady_2nd_order_bounded_cls = unsteady_2nd_order_bounded_cls
    """
    unsteady_2nd_order_bounded child of methods.
    """
    unsteady_global_time: unsteady_global_time_cls = unsteady_global_time_cls
    """
    unsteady_global_time child of methods.
    """
    accelerated_non_iterative_time_marching: accelerated_non_iterative_time_marching_cls = accelerated_non_iterative_time_marching_cls
    """
    accelerated_non_iterative_time_marching child of methods.
    """
    convergence_acceleration_for_stretched_meshes: convergence_acceleration_for_stretched_meshes_cls = convergence_acceleration_for_stretched_meshes_cls
    """
    convergence_acceleration_for_stretched_meshes child of methods.
    """
    expert: expert_cls = expert_cls
    """
    expert child of methods.
    """
    frozen_flux: frozen_flux_cls = frozen_flux_cls
    """
    frozen_flux child of methods.
    """
    gradient_scheme: gradient_scheme_cls = gradient_scheme_cls
    """
    gradient_scheme child of methods.
    """
    high_order_term_relaxation: high_order_term_relaxation_cls = high_order_term_relaxation_cls
    """
    high_order_term_relaxation child of methods.
    """
    multiphase_numerics: multiphase_numerics_cls = multiphase_numerics_cls
    """
    multiphase_numerics child of methods.
    """
    nb_gradient_boundary_option: nb_gradient_boundary_option_cls = nb_gradient_boundary_option_cls
    """
    nb_gradient_boundary_option child of methods.
    """
    nita: nita_cls = nita_cls
    """
    nita child of methods.
    """
    nita_expert_controls: nita_expert_controls_cls = nita_expert_controls_cls
    """
    nita_expert_controls child of methods.
    """
    overset: overset_cls = overset_cls
    """
    overset child of methods.
    """
    phase_based_vof_discretization: phase_based_vof_discretization_cls = phase_based_vof_discretization_cls
    """
    phase_based_vof_discretization child of methods.
    """
    reduced_rank_extrapolation: reduced_rank_extrapolation_cls = reduced_rank_extrapolation_cls
    """
    reduced_rank_extrapolation child of methods.
    """
    reduced_rank_extrapolation_options: reduced_rank_extrapolation_options_cls = reduced_rank_extrapolation_options_cls
    """
    reduced_rank_extrapolation_options child of methods.
    """
    residual_smoothing: residual_smoothing_cls = residual_smoothing_cls
    """
    residual_smoothing child of methods.
    """
    vof_numerics: vof_numerics_cls = vof_numerics_cls
    """
    vof_numerics child of methods.
    """
    warped_face_gradient_correction: warped_face_gradient_correction_cls = warped_face_gradient_correction_cls
    """
    warped_face_gradient_correction child of methods.
    """
    command_names = \
        ['set_solution_methods_to_default']

    set_solution_methods_to_default: set_solution_methods_to_default_cls = set_solution_methods_to_default_cls
    """
    set_solution_methods_to_default command of methods.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .graphics import graphics as graphics_cls
from .surfaces_1 import surfaces as surfaces_cls
class results(Group):
    """
    'results' child.
    """

    fluent_name = "results"

    child_names = \
        ['graphics', 'surfaces']

    graphics: graphics_cls = graphics_cls
    """
    graphics child of results.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of results.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .background_1 import background as background_cls
from .color_filter import color_filter as color_filter_cls
from .foreground_1 import foreground as foreground_cls
from .on import on as on_cls
from .pixel_size import pixel_size as pixel_size_cls
class video(Group):
    """
    Enter the video window options menu.
    """

    fluent_name = "video"

    child_names = \
        ['background', 'color_filter', 'foreground', 'on', 'pixel_size']

    background: background_cls = background_cls
    """
    background child of video.
    """
    color_filter: color_filter_cls = color_filter_cls
    """
    color_filter child of video.
    """
    foreground: foreground_cls = foreground_cls
    """
    foreground child of video.
    """
    on: on_cls = on_cls
    """
    on child of video.
    """
    pixel_size: pixel_size_cls = pixel_size_cls
    """
    pixel_size child of video.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .refine_mesh import refine_mesh as refine_mesh_cls
from .boundary_zones import boundary_zones as boundary_zones_cls
from .layer_count import layer_count as layer_count_cls
from .parameters import parameters as parameters_cls
class multi_layer_refinement(Group):
    """
    Enter the multiple boundary layer refinement menu.
    """

    fluent_name = "multi-layer-refinement"

    command_names = \
        ['refine_mesh', 'boundary_zones', 'layer_count', 'parameters']

    refine_mesh: refine_mesh_cls = refine_mesh_cls
    """
    refine_mesh command of multi_layer_refinement.
    """
    boundary_zones: boundary_zones_cls = boundary_zones_cls
    """
    boundary_zones command of multi_layer_refinement.
    """
    layer_count: layer_count_cls = layer_count_cls
    """
    layer_count command of multi_layer_refinement.
    """
    parameters: parameters_cls = parameters_cls
    """
    parameters command of multi_layer_refinement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .value import value as value_cls
from .profile_name import profile_name as profile_name_cls
from .field_name import field_name as field_name_cls
from .udf import udf as udf_cls
class v2(Group):
    """
    'v2' child.
    """

    fluent_name = "v2"

    child_names = \
        ['option', 'value', 'profile_name', 'field_name', 'udf']

    option: option_cls = option_cls
    """
    option child of v2.
    """
    value: value_cls = value_cls
    """
    value child of v2.
    """
    profile_name: profile_name_cls = profile_name_cls
    """
    profile_name child of v2.
    """
    field_name: field_name_cls = field_name_cls
    """
    field_name child of v2.
    """
    udf: udf_cls = udf_cls
    """
    udf child of v2.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .constant_1 import constant as constant_cls
from .variable_1 import variable as variable_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['option', 'constant', 'variable']

    option: option_cls = option_cls
    """
    option child of options.
    """
    constant: constant_cls = constant_cls
    """
    constant child of options.
    """
    variable: variable_cls = variable_cls
    """
    variable child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class predict_next(Boolean):
    """
    Applies a predictor algorithm for computing initial condition at time step n+1.
    """

    fluent_name = "predict-next?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class surface_mesh:
    fluent_name = ...
    command_names = ...

    def delete(self, surface: str):
        """
        Delete surface mesh.
        
        Parameters
        ----------
            surface : str
                'surface' child.
        
        """

    def display(self, ):
        """
        Display surface meshes.
        """

    def read(self, filename: str, unit: str):
        """
        Read surface meshes.
        
        Parameters
        ----------
            filename : str
                'filename' child.
            unit : str
                'unit' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .check_mapped_interface_quality import check_mapped_interface_quality as check_mapped_interface_quality_cls
from .complete import complete as complete_cls
from .tol_percentage_increment import tol_percentage_increment as tol_percentage_increment_cls
class improve_quality(Command):
    """
    Improve mesh interface quality.
    
    Parameters
    ----------
        check_mapped_interface_quality : bool
            Check Mapped Interface Qaulity.
        complete : bool
            Continue to improve the mapped interface quality.
        tol_percentage_increment : real
            'tol_percentage_increment' child.
    
    """

    fluent_name = "improve-quality"

    argument_names = \
        ['check_mapped_interface_quality', 'complete',
         'tol_percentage_increment']

    check_mapped_interface_quality: check_mapped_interface_quality_cls = check_mapped_interface_quality_cls
    """
    check_mapped_interface_quality argument of improve_quality.
    """
    complete: complete_cls = complete_cls
    """
    complete argument of improve_quality.
    """
    tol_percentage_increment: tol_percentage_increment_cls = tol_percentage_increment_cls
    """
    tol_percentage_increment argument of improve_quality.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_10 import option as option_cls
from .lewis_number import lewis_number as lewis_number_cls
from .value_1 import value as value_cls
from .species_diffusivity import species_diffusivity as species_diffusivity_cls
from .multicomponent import multicomponent as multicomponent_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
class mass_diffusivity(Group):
    """
    'mass_diffusivity' child.
    """

    fluent_name = "mass-diffusivity"

    child_names = \
        ['option', 'lewis_number', 'value', 'species_diffusivity',
         'multicomponent', 'user_defined_function']

    option: option_cls = option_cls
    """
    option child of mass_diffusivity.
    """
    lewis_number: lewis_number_cls = lewis_number_cls
    """
    lewis_number child of mass_diffusivity.
    """
    value: value_cls = value_cls
    """
    value child of mass_diffusivity.
    """
    species_diffusivity: species_diffusivity_cls = species_diffusivity_cls
    """
    species_diffusivity child of mass_diffusivity.
    """
    multicomponent: multicomponent_cls = multicomponent_cls
    """
    multicomponent child of mass_diffusivity.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of mass_diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fixed_cycle_parameters import fixed_cycle_parameters as fixed_cycle_parameters_cls
from .coarsening_parameters import coarsening_parameters as coarsening_parameters_cls
from .smoother_type import smoother_type as smoother_type_cls
class scalar_parameters(Group):
    """
    'scalar_parameters' child.
    """

    fluent_name = "scalar-parameters"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters', 'smoother_type']

    fixed_cycle_parameters: fixed_cycle_parameters_cls = fixed_cycle_parameters_cls
    """
    fixed_cycle_parameters child of scalar_parameters.
    """
    coarsening_parameters: coarsening_parameters_cls = coarsening_parameters_cls
    """
    coarsening_parameters child of scalar_parameters.
    """
    smoother_type: smoother_type_cls = smoother_type_cls
    """
    smoother_type child of scalar_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .print_3 import print as print_cls
from .write_2 import write as write_cls
class histogram(Group):
    """
    'histogram' child.
    """

    fluent_name = "histogram"

    command_names = \
        ['print', 'write']

    print: print_cls = print_cls
    """
    print command of histogram.
    """
    write: write_cls = write_cls
    """
    write command of histogram.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .angular import angular as angular_cls
from .p_jump import p_jump as p_jump_cls
from .ai import ai as ai_cls
from .aj import aj as aj_cls
from .ak import ak as ak_cls
from .x_origin import x_origin as x_origin_cls
from .y_origin import y_origin as y_origin_cls
from .z_origin import z_origin as z_origin_cls
from .shift_x import shift_x as shift_x_cls
from .shift_y import shift_y as shift_y_cls
from .shift_z import shift_z as shift_z_cls
from .per_angle import per_angle as per_angle_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'angular', 'p_jump',
         'ai', 'aj', 'ak', 'x_origin', 'y_origin', 'z_origin', 'shift_x',
         'shift_y', 'shift_z', 'per_angle']

    name: name_cls = name_cls
    """
    name child of phase_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    angular: angular_cls = angular_cls
    """
    angular child of phase_child.
    """
    p_jump: p_jump_cls = p_jump_cls
    """
    p_jump child of phase_child.
    """
    ai: ai_cls = ai_cls
    """
    ai child of phase_child.
    """
    aj: aj_cls = aj_cls
    """
    aj child of phase_child.
    """
    ak: ak_cls = ak_cls
    """
    ak child of phase_child.
    """
    x_origin: x_origin_cls = x_origin_cls
    """
    x_origin child of phase_child.
    """
    y_origin: y_origin_cls = y_origin_cls
    """
    y_origin child of phase_child.
    """
    z_origin: z_origin_cls = z_origin_cls
    """
    z_origin child of phase_child.
    """
    shift_x: shift_x_cls = shift_x_cls
    """
    shift_x child of phase_child.
    """
    shift_y: shift_y_cls = shift_y_cls
    """
    shift_y child of phase_child.
    """
    shift_z: shift_z_cls = shift_z_cls
    """
    shift_z child of phase_child.
    """
    per_angle: per_angle_cls = per_angle_cls
    """
    per_angle child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_2 import enabled as enabled_cls
from .global_courant_number import global_courant_number as global_courant_number_cls
from .initial_time_step_size import initial_time_step_size as initial_time_step_size_cls
from .fixed_time_step_size import fixed_time_step_size as fixed_time_step_size_cls
from .min_time_step_size import min_time_step_size as min_time_step_size_cls
from .max_time_step_size import max_time_step_size as max_time_step_size_cls
from .min_step_change_factor import min_step_change_factor as min_step_change_factor_cls
from .max_step_change_factor import max_step_change_factor as max_step_change_factor_cls
from .update_interval import update_interval as update_interval_cls
class mp_specific_time_stepping(Group):
    """
    'mp_specific_time_stepping' child.
    """

    fluent_name = "mp-specific-time-stepping"

    child_names = \
        ['enabled', 'global_courant_number', 'initial_time_step_size',
         'fixed_time_step_size', 'min_time_step_size', 'max_time_step_size',
         'min_step_change_factor', 'max_step_change_factor',
         'update_interval']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of mp_specific_time_stepping.
    """
    global_courant_number: global_courant_number_cls = global_courant_number_cls
    """
    global_courant_number child of mp_specific_time_stepping.
    """
    initial_time_step_size: initial_time_step_size_cls = initial_time_step_size_cls
    """
    initial_time_step_size child of mp_specific_time_stepping.
    """
    fixed_time_step_size: fixed_time_step_size_cls = fixed_time_step_size_cls
    """
    fixed_time_step_size child of mp_specific_time_stepping.
    """
    min_time_step_size: min_time_step_size_cls = min_time_step_size_cls
    """
    min_time_step_size child of mp_specific_time_stepping.
    """
    max_time_step_size: max_time_step_size_cls = max_time_step_size_cls
    """
    max_time_step_size child of mp_specific_time_stepping.
    """
    min_step_change_factor: min_step_change_factor_cls = min_step_change_factor_cls
    """
    min_step_change_factor child of mp_specific_time_stepping.
    """
    max_step_change_factor: max_step_change_factor_cls = max_step_change_factor_cls
    """
    max_step_change_factor child of mp_specific_time_stepping.
    """
    update_interval: update_interval_cls = update_interval_cls
    """
    update_interval child of mp_specific_time_stepping.
    """



"""Module containing System Coupling-related functionality."""

from dataclasses import dataclass
import os
from typing import List
import xml.etree.ElementTree as XmlET


@dataclass
class Variable:
    name: str
    display_name: str
    tensor_type: str
    is_extensive: bool
    location: str
    quantity_type: str


@dataclass
class Region:
    name: str
    display_name: str
    topology: str
    input_variables: List[str]
    output_variables: List[str]


class SystemCoupling:
    """Wrap a System Coupling object, adding methods to discover more about the
    System Coupling related setup and to help solving a System Coupling analysis.

    Methods
    -------
    __getattr__
    get_variables
    get_regions
    get_analysis_type
    connect
    solve
    """

    def __init__(self, solver):
        self._solver = solver
        # version check - this requires Fluent 2024 R1 or newer.
        fluent_version = self._solver.get_fluent_version()
        if float(fluent_version[:-2]) < 24.1:
            raise RuntimeError(
                f"Fluent version is {fluent_version}. PySystemCoupling integration requires Fluent 24.1.0 or later."
            )

    @property
    def participant_type(self) -> str:
        return "FLUENT"

    def get_variables(self) -> List[Variable]:
        return self.__get_syc_setup()["variables"]

    def get_regions(self) -> List[Region]:
        return self.__get_syc_setup()["regions"]

    def get_analysis_type(self) -> str:
        return self.__get_syc_setup()["analysis-type"]

    def connect(self, host: str, port: int, name: str) -> None:
        self._solver.setup.models.system_coupling.connect_parallel(
            schost=host, scport=port, scname=name
        )

    def solve(self) -> None:
        self._solver.setup.models.system_coupling.init_and_solve()

    def __get_syc_setup(self) -> dict:
        def get_scp_string() -> str:
            """Get SCP file contents in the form of the XML string."""
            scp_file_name = "fluent.scp"
            self._solver.setup.models.system_coupling.write_scp_file(
                file_name=scp_file_name
            )
            assert os.path.exists(
                scp_file_name
            ), "ERROR: could not create System Coupling .scp file"

            with open(scp_file_name, "r") as f:
                xml_string = f.read()

            os.remove(scp_file_name)
            return xml_string

        def get_name(xml_element) -> str:
            return xml_element.find("Name").text

        def get_display_name(xml_element) -> str:
            display_name_elem = xml_element.find("DisplayName")
            if display_name_elem is not None:
                return display_name_elem.text
            else:
                return get_name(xml_element)

        def get_tensor_type(variable) -> str:
            tensor_type_elem = variable.find("TensorType")
            if tensor_type_elem is not None:
                return tensor_type_elem.text

            if get_name(variable) in {"force", "lorentz-force"}:
                return "Vector"
            else:
                return "Scalar"

        def get_is_extensive(variable) -> bool:
            is_extensive_elem = variable.find("IsExtensive")
            if is_extensive_elem is not None:
                is_ext_map = {"True": True, "False": False}
                return is_ext_map[is_extensive_elem.text]

            ext_vars = {
                "force",
                "lortentz-force",
                "heatrate",
                "heatflow",
                "mass-flow-rate",
            }
            if get_name(variable) in ext_vars:
                return True
            else:
                return False

        def get_location(variable) -> str:
            # SCP file contents for location are not always correct,
            # so do not rely on that.
            # This has to do with old vs. new APIs. Here, assume
            # only new APIs are used, so all variables are on elements,
            # except displacements.
            if get_name(variable) == "displacement":
                return "Node"
            else:
                return "Element"

        def get_quantity_type(variable) -> str:
            quantity_type_elem = variable.find("QuantityType")
            if quantity_type_elem is not None:
                return quantity_type_elem.text
            else:
                return "Unspecified"

        setup_info = dict()

        xml_root = XmlET.ElementTree(XmlET.fromstring(get_scp_string()))
        cosim_control = xml_root.find("./CosimulationControl")

        setup_info["analysis-type"] = cosim_control.find("AnalysisType").text

        setup_info["variables"] = list()
        for variable in cosim_control.find("Variables").findall("Variable"):
            setup_info["variables"].append(
                Variable(
                    name=get_name(variable),
                    display_name=get_display_name(variable),
                    tensor_type=get_tensor_type(variable),
                    is_extensive=get_is_extensive(variable),
                    location=get_location(variable),
                    quantity_type=get_quantity_type(variable),
                )
            )

        regions = cosim_control.find("Regions").findall("Region")
        setup_info["regions"] = [
            Region(
                name=get_name(region),
                display_name=get_display_name(region),
                topology=region.find("Topology").text,
                input_variables=[var.text for var in region.find("InputVariables")],
                output_variables=[var.text for var in region.find("OutputVariables")],
            )
            for region in regions
        ]

        return setup_info



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .inlet_diffusion_1 import inlet_diffusion as inlet_diffusion_cls
from .thermal_diffusion import thermal_diffusion as thermal_diffusion_cls
from .thickened_flame_model import thickened_flame_model as thickened_flame_model_cls
from .diffusion_energy_source import diffusion_energy_source as diffusion_energy_source_cls
from .multi_component_diffusion_mf import multi_component_diffusion_mf as multi_component_diffusion_mf_cls
from .multi_component_diffusion import multi_component_diffusion as multi_component_diffusion_cls
from .liquid_energy_diffusion import liquid_energy_diffusion as liquid_energy_diffusion_cls
from .save_gradients import save_gradients as save_gradients_cls
from .species_migration import species_migration as species_migration_cls
from .species_transport_expert import species_transport_expert as species_transport_expert_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['inlet_diffusion', 'thermal_diffusion', 'thickened_flame_model',
         'diffusion_energy_source', 'multi_component_diffusion_mf',
         'multi_component_diffusion', 'liquid_energy_diffusion',
         'save_gradients', 'species_migration', 'species_transport_expert']

    inlet_diffusion: inlet_diffusion_cls = inlet_diffusion_cls
    """
    inlet_diffusion child of options.
    """
    thermal_diffusion: thermal_diffusion_cls = thermal_diffusion_cls
    """
    thermal_diffusion child of options.
    """
    thickened_flame_model: thickened_flame_model_cls = thickened_flame_model_cls
    """
    thickened_flame_model child of options.
    """
    diffusion_energy_source: diffusion_energy_source_cls = diffusion_energy_source_cls
    """
    diffusion_energy_source child of options.
    """
    multi_component_diffusion_mf: multi_component_diffusion_mf_cls = multi_component_diffusion_mf_cls
    """
    multi_component_diffusion_mf child of options.
    """
    multi_component_diffusion: multi_component_diffusion_cls = multi_component_diffusion_cls
    """
    multi_component_diffusion child of options.
    """
    liquid_energy_diffusion: liquid_energy_diffusion_cls = liquid_energy_diffusion_cls
    """
    liquid_energy_diffusion child of options.
    """
    save_gradients: save_gradients_cls = save_gradients_cls
    """
    save_gradients child of options.
    """
    species_migration: species_migration_cls = species_migration_cls
    """
    species_migration child of options.
    """
    species_transport_expert: species_transport_expert_cls = species_transport_expert_cls
    """
    species_transport_expert child of options.
    """



"""Module containing class encapsulating Fluent connection."""
from typing import Any

from ansys.fluent.core.fluent_connection import FluentConnection
from ansys.fluent.core.session_pure_meshing import PureMeshing
from ansys.fluent.core.session_solver import Solver


class Meshing(PureMeshing):
    """Encapsulates a Fluent meshing session. A ``tui`` object
    for meshing TUI commanding, and ``meshing`` and ``workflow``
    objects for access to task-based meshing workflows are all
    exposed here. A ``switch_to_solver`` method is available
    in this mode."""

    def __init__(
        self,
        fluent_connection: FluentConnection,
    ):
        """Meshing session.

        Args:
            fluent_connection (:ref:`ref_fluent_connection`): Encapsulates a Fluent connection.
        """
        super(Meshing, self).__init__(fluent_connection=fluent_connection)
        self.switch_to_solver = lambda: self._switch_to_solver()
        self.switched = False

    def _switch_to_solver(self) -> Any:
        self.tui.switch_to_solution_mode("yes")
        solver_session = Solver(fluent_connection=self.fluent_connection)
        delattr(self, "switch_to_solver")
        self.switched = True
        return solver_session

    @property
    def tui(self):
        """Instance of ``main_menu`` on which Fluent's SolverTUI methods can be
        executed."""
        return super(Meshing, self).tui if not self.switched else None

    @property
    def meshing(self):
        """Datamodel root of meshing."""
        return super(Meshing, self).meshing if not self.switched else None

    @property
    def workflow(self):
        """Datamodel root of workflow."""
        return super(Meshing, self).workflow if not self.switched else None

    @property
    def PartManagement(self):
        """Datamodel root of PartManagement."""
        return super(Meshing, self).PartManagement if not self.switched else None

    @property
    def PMFileManagement(self):
        """Datamodel root of PMFileManagement."""
        return super(Meshing, self).PMFileManagement if not self.switched else None

    @property
    def preferences(self):
        """Datamodel root of preferences."""
        return super(Meshing, self).preferences if not self.switched else None



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .adaptive_time_stepping import adaptive_time_stepping as adaptive_time_stepping_cls
from .cfl_based_adaptive_time_stepping import cfl_based_adaptive_time_stepping as cfl_based_adaptive_time_stepping_cls
from .data_sampling_1 import data_sampling as data_sampling_cls
from .transient_controls import transient_controls as transient_controls_cls
from .dual_time_iterate import dual_time_iterate as dual_time_iterate_cls
from .iterate import iterate as iterate_cls
class run_calculation(Group):
    """
    'run_calculation' child.
    """

    fluent_name = "run-calculation"

    child_names = \
        ['adaptive_time_stepping', 'cfl_based_adaptive_time_stepping',
         'data_sampling', 'transient_controls']

    adaptive_time_stepping: adaptive_time_stepping_cls = adaptive_time_stepping_cls
    """
    adaptive_time_stepping child of run_calculation.
    """
    cfl_based_adaptive_time_stepping: cfl_based_adaptive_time_stepping_cls = cfl_based_adaptive_time_stepping_cls
    """
    cfl_based_adaptive_time_stepping child of run_calculation.
    """
    data_sampling: data_sampling_cls = data_sampling_cls
    """
    data_sampling child of run_calculation.
    """
    transient_controls: transient_controls_cls = transient_controls_cls
    """
    transient_controls child of run_calculation.
    """
    command_names = \
        ['dual_time_iterate', 'iterate']

    dual_time_iterate: dual_time_iterate_cls = dual_time_iterate_cls
    """
    dual_time_iterate command of run_calculation.
    """
    iterate: iterate_cls = iterate_cls
    """
    iterate command of run_calculation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class moving_mesh_velocity:
    fluent_name = ...
    command_names = ...

    def list_properties(self, object_at: int):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_at : int
                'object_at' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class database:
    fluent_name = ...
    child_names = ...
    database_type = ...
    command_names = ...

    def copy_by_formula(self, type: str, formula: str):
        """
        Copy a material from the database (pick by formula).
        
        Parameters
        ----------
            type : str
                'type' child.
            formula : str
                'formula' child.
        
        """

    def copy_by_name(self, type: str, name: str):
        """
        Copy a material from the database (pick by name).
        
        Parameters
        ----------
            type : str
                'type' child.
            name : str
                'name' child.
        
        """

    def list_materials(self, ):
        """
        List all materials in the database.
        """

    def list_properties(self, name: str):
        """
        List the properties of a material in the database.
        
        Parameters
        ----------
            name : str
                'name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .acoustics_wave_equation_controls import acoustics_wave_equation_controls as acoustics_wave_equation_controls_cls
from .advanced import advanced as advanced_cls
from .contact_solution_controls import contact_solution_controls as contact_solution_controls_cls
from .courant_number import courant_number as courant_number_cls
from .equations import equations as equations_cls
from .limits import limits as limits_cls
from .p_v_controls import p_v_controls as p_v_controls_cls
from .relaxation_factor_1 import relaxation_factor as relaxation_factor_cls
from .set_controls_to_default import set_controls_to_default as set_controls_to_default_cls
from .under_relaxation import under_relaxation as under_relaxation_cls
class controls(Group):
    """
    'controls' child.
    """

    fluent_name = "controls"

    child_names = \
        ['acoustics_wave_equation_controls', 'advanced',
         'contact_solution_controls', 'courant_number', 'equations', 'limits',
         'p_v_controls', 'relaxation_factor', 'set_controls_to_default',
         'under_relaxation']

    acoustics_wave_equation_controls: acoustics_wave_equation_controls_cls = acoustics_wave_equation_controls_cls
    """
    acoustics_wave_equation_controls child of controls.
    """
    advanced: advanced_cls = advanced_cls
    """
    advanced child of controls.
    """
    contact_solution_controls: contact_solution_controls_cls = contact_solution_controls_cls
    """
    contact_solution_controls child of controls.
    """
    courant_number: courant_number_cls = courant_number_cls
    """
    courant_number child of controls.
    """
    equations: equations_cls = equations_cls
    """
    equations child of controls.
    """
    limits: limits_cls = limits_cls
    """
    limits child of controls.
    """
    p_v_controls: p_v_controls_cls = p_v_controls_cls
    """
    p_v_controls child of controls.
    """
    relaxation_factor: relaxation_factor_cls = relaxation_factor_cls
    """
    relaxation_factor child of controls.
    """
    set_controls_to_default: set_controls_to_default_cls = set_controls_to_default_cls
    """
    set_controls_to_default child of controls.
    """
    under_relaxation: under_relaxation_cls = under_relaxation_cls
    """
    under_relaxation child of controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .host_file import host_file as host_file_cls
class save_hosts(Command):
    """
    Write a hosts file.
    
    Parameters
    ----------
        host_file : str
            'host_file' child.
    
    """

    fluent_name = "save-hosts"

    argument_names = \
        ['host_file']

    host_file: host_file_cls = host_file_cls
    """
    host_file argument of save_hosts.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .in_plane import in_plane as in_plane_cls
from .fixed_length import fixed_length as fixed_length_cls
from .x_comp import x_comp as x_comp_cls
from .y_comp import y_comp as y_comp_cls
from .z_comp import z_comp as z_comp_cls
from .scale_head import scale_head as scale_head_cls
from .color import color as color_cls
class vector_opt(Group):
    """
    'vector_opt' child.
    """

    fluent_name = "vector-opt"

    child_names = \
        ['in_plane', 'fixed_length', 'x_comp', 'y_comp', 'z_comp',
         'scale_head', 'color']

    in_plane: in_plane_cls = in_plane_cls
    """
    in_plane child of vector_opt.
    """
    fixed_length: fixed_length_cls = fixed_length_cls
    """
    fixed_length child of vector_opt.
    """
    x_comp: x_comp_cls = x_comp_cls
    """
    x_comp child of vector_opt.
    """
    y_comp: y_comp_cls = y_comp_cls
    """
    y_comp child of vector_opt.
    """
    z_comp: z_comp_cls = z_comp_cls
    """
    z_comp child of vector_opt.
    """
    scale_head: scale_head_cls = scale_head_cls
    """
    scale_head child of vector_opt.
    """
    color: color_cls = color_cls
    """
    color child of vector_opt.
    """
